@@ -19,20 +19,21 @@
 #define KEEPASSX_KDBX4WRITER_H
 
 #include "KdbxWriter.h"
+#include "format/KdbxXmlWriter.h"
 
 /**
  * KDBX4 writer implementation.
  */
 class Kdbx4Writer : public KdbxWriter
 {
-Q_DECLARE_TR_FUNCTIONS(Kdbx4Writer)
+    Q_DECLARE_TR_FUNCTIONS(Kdbx4Writer)
 
 public:
     bool writeDatabase(QIODevice* device, Database* db) override;
 
 private:
     bool writeInnerHeaderField(QIODevice* device, KeePass2::InnerHeaderFieldID fieldId, const QByteArray& data);
-    void writeAttachments(QIODevice* device, Database* db);
+    KdbxXmlWriter::BinaryIdxMap writeAttachments(QIODevice* device, Database* db);
     static bool serializeVariantMap(const QVariantMap& map, QByteArray& outputBytes);
 };
 
