@@ -18,24 +18,29 @@
 #include "Font.h"
 
 #include <QFontDatabase>
+#include <QGuiApplication>
 
 QFont Font::defaultFont()
 {
-    return QFontDatabase::systemFont(QFontDatabase::GeneralFont);
+    return qApp->font();
 }
 
 QFont Font::fixedFont()
 {
-    QFont fixedFont = QFontDatabase::systemFont(QFontDatabase::FixedFont);
+    auto fixedFont = QFontDatabase::systemFont(QFontDatabase::FixedFont);
 
 #ifdef Q_OS_WIN
     // try to use Consolas on Windows, because the default Courier New has too many similar characters
-    QFont consolasFont = QFontDatabase().font("Consolas", fixedFont.styleName(), fixedFont.pointSize());
-    const QFont defaultFont;
-    if (fixedFont != defaultFont) {
+    auto consolasFont = QFontDatabase().font("Consolas", fixedFont.styleName(), fixedFont.pointSize());
+    if (consolasFont.family().contains("consolas", Qt::CaseInsensitive)) {
         fixedFont = consolasFont;
+        // Bump up the font size by one point to match the default font
+        fixedFont.setPointSize(fixedFont.pointSize() + 1);
     }
 #endif
-
+#ifdef Q_OS_MACOS
+    // Qt doesn't choose a monospace font correctly on macOS
+    fixedFont = QFontDatabase().font("Menlo", fixedFont.styleName(), fixedFont.pointSize());
+#endif
     return fixedFont;
 }
